@@ -2,15 +2,22 @@ import copy
 import errno
 import itertools
 import os
+import re
 import shutil
 from dataclasses import dataclass, field
 from enum import Enum
-from typing import Any, Callable, Sequence, Type
+from textwrap import dedent
+from typing import Any, Callable, Optional, Sequence, Type
 
-import smart_open
 import yaml
 
 
+def clean_multiline(string: str) -> str:
+    string = dedent(string.strip())
+    string = re.sub(r'\s*\n\s*', ' ', string)
+    return string
+
+
 def merge_nested_dicts(*dicts: Sequence[dict]) -> dict:
     # all the merging is done in a new dict, not in place
     out = {}
@@ -209,10 +216,11 @@ def type_evaluator(field_type: Type[Any]) -> Callable:
     return _type_fn
 
 
-def read_raw_file(file_path: str) -> str:
-    """For reading the content of a file from multiple
-    providers."""
-    with smart_open.open(file_path, mode='r', encoding='utf-8') as f:
+def read_raw_file(file_path: str,
+                  open_fn: Optional[Callable] = None) -> str:
+    """For reading the content of a file."""
+    open_fn = open_fn or open
+    with open_fn(file_path, mode='r', encoding='utf-8') as f:
         content = f.read()
     return content
 
